"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var react_component_event_listener_1 = require("@fluentui/react-component-event-listener");
var enzyme_1 = require("enzyme");
var React = require("react");
// @ts-ignore
var simulant = require("simulant");
describe('EventListener', function () {
    describe('listener', function () {
        it('handles events on `target`', function () {
            var onClick = jest.fn();
            var onKeyDown = jest.fn();
            enzyme_1.mount(React.createElement(React.Fragment, null,
                React.createElement(react_component_event_listener_1.EventListener, { listener: onClick, targetRef: react_component_event_listener_1.documentRef, type: "click" }),
                React.createElement(react_component_event_listener_1.EventListener, { listener: onKeyDown, targetRef: react_component_event_listener_1.documentRef, type: "keydown" })));
            simulant.fire(document, 'click');
            simulant.fire(document, 'keydown');
            expect(onClick).toHaveBeenCalledTimes(1);
            expect(onClick).toHaveBeenCalledWith(expect.objectContaining({ type: 'click' }));
            expect(onKeyDown).toHaveBeenCalledTimes(1);
            expect(onKeyDown).toHaveBeenCalledWith(expect.objectContaining({ type: 'keydown' }));
        });
        it('unsubscribes correctly', function () {
            var onClick = jest.fn();
            var wrapper = enzyme_1.mount(React.createElement(react_component_event_listener_1.EventListener, { listener: onClick, targetRef: react_component_event_listener_1.documentRef, type: "click" }));
            wrapper.unmount();
            simulant.fire(document, 'click');
            expect(onClick).not.toHaveBeenCalled();
        });
    });
    describe('capture', function () {
        it('passes "false" by default', function () {
            var addEventListener = jest.spyOn(document, 'addEventListener');
            var removeEventListener = jest.spyOn(document, 'removeEventListener');
            var wrapper = enzyme_1.mount(React.createElement(react_component_event_listener_1.EventListener, { listener: function () { }, targetRef: react_component_event_listener_1.documentRef, type: "click" }));
            wrapper.unmount();
            expect(addEventListener).toHaveBeenCalledWith('click', expect.any(Function), false);
            expect(removeEventListener).toHaveBeenCalledWith('click', expect.any(Function), false);
        });
        it('passes `capture` prop when it is defined', function () {
            var addEventListener = jest.spyOn(document, 'addEventListener');
            var removeEventListener = jest.spyOn(document, 'removeEventListener');
            var wrapper = enzyme_1.mount(React.createElement(react_component_event_listener_1.EventListener, { capture: true, listener: function () { }, targetRef: react_component_event_listener_1.documentRef, type: "click" }));
            wrapper.unmount();
            expect(addEventListener).toHaveBeenCalledWith('click', expect.any(Function), true);
            expect(removeEventListener).toHaveBeenCalledWith('click', expect.any(Function), true);
        });
    });
    describe('type', function () {
        it('handles changes', function () {
            var listener = jest.fn();
            var wrapper = enzyme_1.mount(React.createElement(react_component_event_listener_1.EventListener, { listener: listener, targetRef: react_component_event_listener_1.documentRef, type: "click" }));
            simulant.fire(document, 'click');
            expect(listener).toHaveBeenCalledTimes(1);
            wrapper.setProps({ type: 'scroll' });
            simulant.fire(document, 'scroll');
            expect(listener).toHaveBeenCalledTimes(2);
        });
    });
});
